@@ -3,7 +3,7 @@
 # __Time__ = 13:22
 # __FileName__ = __init__.py
 
-from .ssh_key_maker import generate_ssh_key
+from .ssh_key_maker_bot import generate_ssh_key
 
 
 
